@@ -13,6 +13,7 @@
 #include <dirent.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdio_ext.h>
 #include <unistd.h>
 #include <fnmatch.h>
 #include <limits.h>
@@ -26,13 +27,9 @@
 
 static int filename_select(const struct dirent *d)
 {
-	int len;
-
-	len = strlen(d->d_name);
-	if (len == 1 && d->d_name[0] == '.')
-		return 0;
-	if (len == 2 && d->d_name[0] == '.' &&
-	    d->d_name[1] == '.')
+	if (d->d_name[0] == '.'
+	    && (d->d_name[1] == '\0'
+		|| (d->d_name[1] == '.' && d->d_name[2] == '\0')))
 		return 0;
 	return 1;
 }
@@ -62,17 +59,14 @@ int security_get_boolean_names(char ***names, int *len)
 		rc = -1;
 		goto bad;
 	}
-
-	memset(n, 0, sizeof(char*) * *len);
 	
 	for (i = 0; i < *len; i++) {
-		n[i] = (char*)malloc(sizeof(char)
-				     * (namelist[i]->d_reclen + 1));
+		n[i] = (char*)malloc(_D_ALLOC_NAMLEN(namelist[i]));
 		if (!n[i]) {
 			rc = -1;
 			goto bad_freen;
 		}
-		strncpy(n[i], namelist[i]->d_name, namelist[i]->d_reclen + 1);
+		strcpy(n[i], namelist[i]->d_name);
 	}
 	rc = 0;
 	*names = n;
@@ -83,10 +77,8 @@ out:
 	free(namelist);
 	return rc;
 bad_freen:
-	for (i = 0; i < *len; i++) {
-		if (n[i])
-			free(n[i]);
-	}
+	for (--i; i >= 0; --i)
+		free(n[i]);
 	free(n);
 bad:
 	goto out;
@@ -318,6 +310,7 @@ static int save_booleans(size_t boolcnt, SELboolean *boollist) {
 		char boolname[BUFSIZ];
 		char *buffer;
 		char *inbuf=NULL;
+		__fsetlocking(boolf, FSETLOCKING_BYCALLER);
 		while ((len=getline(&inbuf, &size, boolf)) > 0) {
 			buffer=strdup(inbuf);
 			if (!buffer) goto close_remove_fail;
@@ -420,6 +413,7 @@ int security_load_booleans(char *path) {
 	if (boolf == NULL) 
 	  goto localbool;
 
+	__fsetlocking(boolf, FSETLOCKING_BYCALLER);
 	while (getline(&inbuf, &len, boolf) > 0) {
 		int ret=process_boolean(inbuf, name, sizeof(name), &val);
 		if (ret==-1) 
@@ -436,6 +430,7 @@ localbool:
 
 	if (boolf != NULL) {
 		int ret;
+		__fsetlocking(boolf, FSETLOCKING_BYCALLER);
 		while (getline(&inbuf, &len, boolf) > 0) {
 			ret=process_boolean(inbuf, name, sizeof(name), &val);
 			if (ret==-1) 
