@@ -60,8 +60,11 @@ out:
 	context_free(con);
 	return rc;
 }
-
-static void (*myprintf)(const char *fmt, ...) = &default_printf;
+static void 
+#ifdef __GNUC__
+__attribute__ ((format (printf, 1, 2)))
+#endif
+(*myprintf)(const char *fmt, ...) = &default_printf;
 
 void set_matchpathcon_printf(void (*f)(const char *fmt, ...))
 {
