@@ -4,9 +4,10 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <string.h>
-#include <selinux/selinux.h>
+#include "selinux_internal.h"
 #include <stdio.h>
 #include "policy.h"
+#include "dso.h"
 #include <limits.h>
 
 #define DEFAULT_POLICY_VERSION 15
@@ -37,3 +38,5 @@ int security_policyvers(void)
 
 	return vers;
 }
+hidden_def(security_policyvers)
+
