@@ -48,7 +48,7 @@ int rpm_execcon(unsigned int verified __attribute__((unused)),
 		goto out;
 out:
 
-	if (rc >= 0 || !security_getenforce())
+	if (rc >= 0 || security_getenforce() < 1)
 		rc = execve(filename, argv, envp); 
 
 	context_free(con);
