@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <stdio_ext.h>
 #include <string.h>
 #include <ctype.h>
 #include <stddef.h>
@@ -130,7 +131,8 @@ static void init_selinux_config(void) __attribute__ ((constructor));
 static void init_selinux_config(void)
 {
   int i, *intptr;
-  size_t rootlen, len;
+  size_t line_len;
+  ssize_t len;
   char *line_buf = NULL, *buf_p, *value, *type = NULL, *end;
   FILE *fp;
 
@@ -145,8 +147,8 @@ static void init_selinux_config(void)
   selinux_rootpath = SELINUXDIR;
   fp = fopen(SELINUXCONFIG,"r");
   if (fp) {
-	  while (getline(&line_buf, &len, fp) > 0) {
-		  len = strlen(line_buf); /* reset in case of embedded NUL */
+	  __fsetlocking(fp, FSETLOCKING_BYCALLER);
+	  while ((len = getline(&line_buf, &line_len, fp)) > 0) {
 		  if (line_buf[len - 1] == '\n')
 			  line_buf[len - 1] = 0;
 		  buf_p = line_buf;
@@ -157,9 +159,7 @@ static void init_selinux_config(void)
 
 		  if (!strncasecmp(buf_p, SELINUXTYPETAG, 
 				   sizeof(SELINUXTYPETAG)-1)) {
-			  type = strdup(buf_p+sizeof(SELINUXTYPETAG)-1);
-			  if (!type)
-				  return;
+			  type = strdupa(buf_p+sizeof(SELINUXTYPETAG)-1);
 			  end  = type + strlen(type)-1;
 			  while ((end > type) && 
 				 (isspace(*end) || iscntrl(*end))) {
@@ -190,28 +190,18 @@ static void init_selinux_config(void)
 	  fclose(fp);
   }
 
-  if (!type) {
-	  type = strdup(SELINUXDEFAULT);
-	  if (!type)
-		  return;
-  }
-  rootlen = sizeof(SELINUXDIR) + strlen(type);
-  selinux_policyroot = malloc(rootlen);
-  if (!selinux_policyroot)
-	  return;
-  snprintf(selinux_policyroot, rootlen, "%s%s", 
-	   SELINUXDIR, type);
-  free(type);
+  if (!type)
+	  type = SELINUXDEFAULT;
 
-  for (i = 0; i < NEL; i++) {
-	  len = rootlen + strlen(file_path_suffixes_data.str
-				 + file_path_suffixes_idx[i])+1;
-	  file_paths[i] = malloc(len);
-	  if (!file_paths[i])
+  if (asprintf(&selinux_policyroot, "%s%s", SELINUXDIR, type) == -1)
+	  return;
+
+  for (i = 0; i < NEL; i++)
+	  if (asprintf(&file_paths[i], "%s%s",
+		       selinux_policyroot,
+		       file_path_suffixes_data.str + file_path_suffixes_idx[i])
+	      == -1)
 		  return;
-	  snprintf(file_paths[i], len, "%s%s", selinux_policyroot,
-		   file_path_suffixes_data.str + file_path_suffixes_idx[i]);
-  }
   use_compat_file_path = 0;
 }
 
