@@ -85,11 +85,11 @@ int main(int argc, char **argv)
 		}
 		if (pending != active) {
 			printf("%s --> %s pending: %s\n", names[i],
-			       ( active ? "active" : "inactive"),
-			       ( pending ? "active" : "inactive"));
+			       ( active ? "on" : "off"),
+			       ( pending ? "on" : "off"));
 		} else {
 			printf("%s --> %s\n", names[i],
-			       ( active ? "active" : "inactive"));
+			       ( active ? "on" : "off"));
 		}
 	}
 
